==> cmsmadesimple-1.5.3.tgz: cms/modules/TinyMCE/lang/ext/sk_SK.php <==
<?php
$lang['friendlyname'] = 'TinyMCE WYSIWYG Basic editor';
$lang['uninstalled'] = 'Modul odin&scaron;talovan&yacute;';
$lang['installed'] = 'Modul verzia %s nain&scaron;talovan&yacute;.';
$lang['stripbackgroundtags'] = 'Orezať t&aacute;gy pozadia z CSS';
$lang['source_formatting_text'] = 'Použiť form&aacute;tov&aacute;nie zdroja v  HTML na v&yacute;stupe';
$lang['dropdownblockformats_text'] = 'Blokov&eacute; elementy v dropdown-menu';
$lang['allowtables'] = 'Povoliť pr&aacute;cu s tabuľkami';
$lang['newlinestyle_text'] = '&Scaron;t&yacute;l nov&eacute;ho riadku';
$lang['pstyle'] = 'p &scaron;t&yacute;l';
$lang['brstyle'] = 'br &scaron;t&yacute;l';
$lang['usecompressiontext'] = 'Použiť gz kompresiu';
$lang['usecompressionhelp'] = 'Toto m&ocirc;že zr&yacute;chliť nač&iacute;tavanie TinyMCE editora, ale takisto m&ocirc;že sp&ocirc;sobiť probl&eacute;my na niektor&yacute;ch syst&eacute;moch. Použ&iacute;vajte opatrne.';
$lang['forcedrootblocktext'] = 'Force <p> rootblock';
$lang['forcedrootblockhelp'] = 'Forces the returned content to at least be enclosed in a <p>-tag';
$lang['filepickerstyle'] = 'S&uacute;bory v editore';
$lang['filepickersize'] = 'Okno so s&uacute;bormi';
$lang['allowuploadtext'] = 'Povoliť upload a vytv&aacute;ranie adres&aacute;rov vo FilePickeri (okno pre spr&aacute;vu s&uacute;borov)';
$lang['cannotreadconfig'] = 'Cannot read the file tinyconfig.php directly so TinyMCE will probably not work. You should check the permissions of the file and of the parent dirs, which should be readable for all but only writable for owner.';
$lang['filenameonly'] = 'Uk&aacute;zať n&aacute;zvy s&uacute;borov';
$lang['thumbnailsonly'] = 'Uk&aacute;zať nahľady';
$lang['filenameandthumbnails'] = 'Uk&aacute;zať aj n&aacute;zvy s&uacute;borov aj nahľady';
$lang['skinstext'] = '&Scaron;abl&oacute;na';
$lang['skinvariationtext'] = 'Vari&aacute;cie vzhľadu';
$lang['advancedwarning'] = '<strong>Pozn&aacute;mka!<br/>&Uacute;prava t&yacute;chto nastaven&iacute; m&ocirc;že znefunčniť TinyMCE. Upravujte iba v pr&iacute;pade, že ste sk&uacute;sen&yacute; už&iacute;vateľ. ';
$lang['entityencoding_text'] = 'K&oacute;dovanie ent&iacute;t';
$lang['rawencoding'] = 'Z&aacute;kladn&eacute; k&oacute;dovanie (r&yacute;chlej&scaron;ie, pracuje vo v&auml;č&scaron;ine pr&iacute;padoch)';
$lang['namedencoding'] = 'Named encoding (like &nbsp;)';
$lang['numericencoding'] = 'Numerick&eacute; k&oacute;dovanie (napr. &amp;#160;)';
$lang['show_path_text'] = 'Zobrazovať cestu k elementu na spodnej strane editoru.';
$lang['toolbar_tab'] = 'N&aacute;strojov&aacute; li&scaron;ta';
$lang['toolbar_help'] = 'Tieto voľby by mali obsahovať zoznam mien tlač&iacute;tok/ovl&aacute;dac&iacute;ch prvkov pre vloženie do n&aacute;strojovej li&scaron;ty.';
$lang['toolbar_text'] = 'N&aacute;strojov&aacute; li&scaron;ta';
$lang['toolbarhelptext'] = 'Kliknite pre n&aacute;povedu k toolbaru v TinyMCE-wiki.';
$lang['editor_width_text'] = '&Scaron;&iacute;rka poľa s editorom (width)';
$lang['editor_height_text'] = 'V&yacute;&scaron;ka  poľa s editorom (height)';
$lang['auto'] = 'Automaticky';
$lang['or'] = 'alebo';
$lang['datetimeformat_text'] = 'Form&aacute;t d&aacute;tumu a času';
$lang['timetext'] = 'Čas';
$lang['datetext'] = 'D&aacute;tum';
$lang['datetimeformat_help'] = 'Kliknite pre ďal&scaron;ie inform&aacute;cie k form&aacute;tovaniu d&aacute;tumu a času';
$lang['extraconfigtext'] = 'Extra nastavenia';
$lang['extraconfighelp'] = 'Pozrite TinyMCE-wiki pre n&aacute;povedu';
$lang['customdropdowntext'] = 'Vlastn&yacute; dropdown';
$lang['customdropdownhelp'] = 'Inserts customizable snippets of code/text by selection in a dropdown menu. 
Obvious uses are easy access to tag&#039;s etc. The menu is inserted into toolbar using &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Po spusten&iacute;';
$lang['startenabledhelp'] = 'Unchecking this starts up Tiny-editors in a disabled state. Should be used together with the toggle button.';
$lang['loadcmslinkertext'] = 'Nahrať CMS-linker';
$lang['loadcmslinkerhelp'] = 'Toto generuje k&oacute;d potrebn&yacute; pre pridanie CMS-linkeru  do n&aacute;strojovej li&Scaron;ty';
$lang['cmslinkerstyletext'] = 'CMS-linker - form&aacute;t odkazov';
$lang['cmsselflinkstyle'] = '{cms_selflink}-form&aacute;t (s podporou pretty urls)';
$lang['ahrefstyle'] = '<a href>-form&aacute;t (bez podpory pretty urls)';
$lang['relativeurlstext'] = 'Generovať relat&iacute;vne adresy';
$lang['forcecleanpastetext'] = 'Vyčistiť pri vložen&iacute;';
$lang['forcecleanpastehelp'] = 'Toto zapn&iacute;na odstraňovanie podivn&eacute;ho form&aacute;tovania textu pri vkladan&iacute; textov z wordu.';
$lang['bodycss_text'] = 'CSS &scaron;t&yacute;ly pre tag body';
$lang['bodycss_help'] = 'Nechajte PR&Aacute;ZDNE alebo nastavte pre použitie  v editore. Pozn&aacute;mka: Pre nastavenie bieleho pozadia vložte: background-color:white;';
$lang['includeonlyscreencss_text'] = 'Vložiť len screen CSS';
$lang['includeonlyscreencss_help'] = 'Vybrat&iacute;m tejto možnosti povol&iacute;te prip&aacute;jať do editora na spracovanei iba &scaron;t&yacute;li typu screen.';
$lang['usestaticconfigtext'] = 'Použiť statick&yacute; konfiguračn&yacute; s&uacute;bor';
$lang['usestaticconfighelp'] = 'This can help getting tiny to work on systems where the hosting facility adds stuff like statistics etc. to all output, breaking dynamiccally created javascript config file';
$lang['usestaticconfigwarning'] = 'Warning! You have the static config-file option enabled but your /tmp/ dir is not writable. This will prevent the module from saving the statigc config-file and will most probably render TinyMCE inoperational.';
$lang['showtogglebutton_text'] = 'Zobraziť checkbox pre vypnutie/zapnutie WYSIWYG editora';
$lang['togglewysiwyg'] = 'Zapn&uacute;ť/vypn&uacute;ť WYSIWYG editor';
$lang['styles_tab'] = 'CSS &scaron;t&yacute;ly';
$lang['styles_help'] = 'Pokiaľ toto pole nech&aacute;te pr&aacute;zdne, TinyMCE spracuje Va&scaron;e CSS s&uacute;bory a pon&uacute;kne &scaron;t&yacute;ly už&iacute;vateľovi. Pokiaľ chcete už&iacute;vateľovi pon&uacute;knuť iba vybran&eacute; &scaron;&yacute;ly, &scaron;pecifikujte ich formou &quot;Style 1=style1; Style 2=style2&quot; v prvom nasleduj&uacute;com poli. V ostatn&yacute;ch poliach je m&ocirc;žn&eacute; &scaron;pecifikovať CSS &scaron;t&yacute;ly pre tabuľky, riadky a bunky, ktor&eacute; s&uacute; použit&eacute; v dial&oacute;gov&yacute;ch okn&aacute;ch. Pre pr&aacute;zdne pole bud&uacute; použit&eacute; parametre z hlavn&yacute;ch &scaron;t&yacute;lov.';
$lang['css_styles_text'] = 'Hlavn&eacute;';
$lang['accessdenied'] = 'Pr&iacute;stup zak&aacute;zan&yacute;. Pros&iacute;m skontrolujte si svoje pr&aacute;va.';
$lang['error'] = 'Chyba!';
$lang['submit'] = 'Odoslať';
$lang['update'] = 'Upraviť';
$lang['settings'] = 'Nastavenia';
$lang['settingssaved'] = 'Nastavenia boli uložen&eacute;';
$lang['advancedsaved'] = 'Pokročil&eacute; nastavenia uložen&eacute;';
$lang['toolbarsaved'] = 'N&aacute;strojov&aacute; li&scaron;ta bola uložen&aacute;';
$lang['stylessaved'] = '&Scaron;t&yacute;ly boli uložen&eacute;';
$lang['testareatext'] = 'Textov&aacute; oblasť, nič nebude naru&scaron;en&eacute; zmenami v nej...';
$lang['reset'] = 'Nastavenie na prednastaven&eacute; hodnoty';
$lang['resetall'] = 'Nastavenie v&scaron;etk&yacute;ch nastaven&iacute; na prednastaven&eacute; hodnoty';
$lang['confirmreset'] = 'Ste si ist&yacute;, že chcete obnoviť tieto nastavenia na prednastaven&eacute; hodnoty?';
$lang['confirmresetall'] = 'Ste si ist&yacute;, že chcete obnoviť vśetky nastavenia na prednastaven&eacute; hodnoty?';
$lang['settingsreset'] = 'Tieto nastavenia boli obnoven&eacute; na prednastaven&eacute; hodnoty ';
$lang['allsettingsreset'] = 'V&scaron;etky nastavenia boli obnoven&eacute; na prednastaven&eacute; hodnoty';
$lang['upgraded'] = 'bol aktualizovan&yacute; na verziu';
$lang['customdropdown'] = 'Vlastn&eacute; rozbaľovacie menu';
$lang['cmsmslinker'] = 'Vložiť link do cmsms-str&aacute;nky';
$lang['backend_toolbars'] = 'Nastavenie toolbaru pre back-end';
$lang['frontend_toolbars'] = 'Nastavenie toolbaru pre front-end';
$lang['plugins_tab'] = 'Pluginy';
$lang['plugins_help'] = 'Vyberte si plagin pre aktiv&aacute;ciu. Dokument&aacute;ciu m&ocirc;žete n&aacute;jsť <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">tu</a>-';
$lang['plugins_text'] = 'Pluginy';
$lang['saveplugins'] = 'Uložiť pluginy';
$lang['pluginssaved'] = 'Pluginy uložen&eacute;.';
$lang['youareintext'] = 'Ste v';
$lang['extrastylestext'] = 'Doplnenie do &scaron;t&yacute;lov';
$lang['extrastyleshelp'] = 'Vložene CSS spracuje TinyMCE až po spracovan&iacute; &scaron;t&yacute;lov z CMS made simple.';
$lang['uploadnewfile'] = 'Nov&yacute; s&uacute;bor';
$lang['uploadfile'] = 'Nahrať';
$lang['createnewdir'] = 'Nov&yacute; adres&aacute;r';
$lang['createdir'] = 'Vytvorič';
$lang['nodirname'] = 'Bez n&aacute;zvu adres&aacute;ra';
$lang['direxists'] = 'Adres&aacute;r už existuje';
$lang['newdircreated'] = 'Nov&yacute; adres&aacute;r &uacute;spe&scaron;ne vytvoren&yacute;';
$lang['newdirfailed'] = 'Chyba pri vytvoren&iacute; adres&aacute;ra';
$lang['nofile'] = 'S&uacute;bor nebol nahrat&yacute;';
$lang['filetoobig'] = 'Nahr&aacute;van&yacute; s&uacute;bor je pr&iacute;li&scaron; veľk&yacute;';
$lang['uploadfailed'] = 'Chyba pri pres&uacute;van&uacute; nahrat&eacute;ho s&uacute;boru';
$lang['fileuploaded'] = 'S&uacute;bor &uacute;spe&scaron;ne nain&scaron;talovan&yacute;';
$lang['filepickertitle'] = 'CMSMadeSimple v&yacute;ber s&uacute;boru';
$lang['success'] = '&Uacute;spech';
$lang['fileoperations'] = 'S&uacute;bor oper&aacute;cii';
$lang['thousanddelimiter'] = ',';
$lang['size'] = 'Veľkosť';
$lang['dimensions'] = 'V&yacute;&scaron;kaxdĺžka';
$lang['advanced_tab'] = 'Pokročil&eacute;';
$lang['help'] = '	<h3>Čo rob&iacute; tento modul?</h3>
	<p>Umožňuje použ&iacute;vať TinyMCE WYSIWYG editor na &uacute;pravu obsahu.</p>
	<h3>Ako sa použ&iacute;va?</h3>
	<p>Nain&scaron;talovať, potom &iacute;sť do Uživateľsk&yacute;ch nastaven&iacute; a zvoliť TinyMCE ako V&aacute;&scaron; wysiwyg editor.</p>';
$lang['utmz'] = '156861353.1228691676.223.15.utmccn=(referral)|utmcsr=burner.kuzmany.biz|utmcct=/install/upgrade.php|utmcmd=referral';
$lang['utma'] = '156861353.158291335300466100.1221906470.1229195154.1229197788.231';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.6.4.tgz: cms/modules/TinyMCE/lang/ext/sk_SK.php <==
<?php
$lang['friendlyname'] = 'TinyMCE WYSIWYG Basic editor';
$lang['uninstalled'] = 'Modul odin&scaron;talovan&yacute;';
$lang['installed'] = 'Modul verzia %s nain&scaron;talovan&yacute;.';
$lang['stripbackgroundtags'] = 'Orezať t&aacute;gy pozadia z CSS';
$lang['source_formatting_text'] = 'Použiť form&aacute;tov&aacute;nie zdroja v  HTML na v&yacute;stupe';
$lang['dropdownblockformats_text'] = 'Blokov&eacute; elementy v dropdown-menu';
$lang['allowtables'] = 'Povoliť pr&aacute;cu s tabuľkami';
$lang['newlinestyle_text'] = '&Scaron;t&yacute;l nov&eacute;ho riadku';
$lang['pstyle'] = 'p &scaron;t&yacute;l';
$lang['brstyle'] = 'br &scaron;t&yacute;l';
$lang['usecompressiontext'] = 'Použiť gz kompresiu';
$lang['usecompressionhelp'] = 'Toto m&ocirc;že zr&yacute;chliť nač&iacute;tavanie TinyMCE editora, ale takisto m&ocirc;že sp&ocirc;sobiť probl&eacute;my na niektor&yacute;ch syst&eacute;moch. Použ&iacute;vajte opatrne.';
$lang['forcedrootblocktext'] = 'Force <p> rootblock';
$lang['forcedrootblockhelp'] = 'Forces the returned content to at least be enclosed in a <p>-tag';
$lang['filepickerstyle'] = 'S&uacute;bory v editore';
$lang['filepickersize'] = 'Okno so s&uacute;bormi';
$lang['allowuploadtext'] = 'Povoliť upload a vytv&aacute;ranie adres&aacute;rov vo FilePickeri (okno pre spr&aacute;vu s&uacute;borov)';
$lang['cannotreadconfig'] = 'Cannot read the file tinyconfig.php directly so TinyMCE will probably not work. You should check the permissions of the file and of the parent dirs, which should be readable for all but only writable for owner.';
$lang['filenameonly'] = 'Uk&aacute;zať n&aacute;zvy s&uacute;borov';
$lang['thumbnailsonly'] = 'Uk&aacute;zať nahľady';
$lang['filenameandthumbnails'] = 'Uk&aacute;zať aj n&aacute;zvy s&uacute;borov aj nahľady';
$lang['skinstext'] = '&Scaron;abl&oacute;na';
$lang['skinvariationtext'] = 'Vari&aacute;cie vzhľadu';
$lang['advancedwarning'] = '<strong>Pozn&aacute;mka!<br/>&Uacute;prava t&yacute;chto nastaven&iacute; m&ocirc;že znefunčniť TinyMCE. Upravujte iba v pr&iacute;pade, že ste sk&uacute;sen&yacute; už&iacute;vateľ. ';
$lang['entityencoding_text'] = 'K&oacute;dovanie ent&iacute;t';
$lang['rawencoding'] = 'Z&aacute;kladn&eacute; k&oacute;dovanie (r&yacute;chlej&scaron;ie, pracuje vo v&auml;č&scaron;ine pr&iacute;padoch)';
$lang['namedencoding'] = 'Named encoding (like &nbsp;)';
$lang['numericencoding'] = 'Numerick&eacute; k&oacute;dovanie (napr. &amp;#160;)';
$lang['show_path_text'] = 'Zobrazovať cestu k elementu na spodnej strane editoru.';
$lang['toolbar_tab'] = 'N&aacute;strojov&aacute; li&scaron;ta';
$lang['toolbar_help'] = 'Tieto voľby by mali obsahovať zoznam mien tlač&iacute;tok/ovl&aacute;dac&iacute;ch prvkov pre vloženie do n&aacute;strojovej li&scaron;ty.';
$lang['toolbar_text'] = 'N&aacute;strojov&aacute; li&scaron;ta';
$lang['toolbarhelptext'] = 'Kliknite pre n&aacute;povedu k toolbaru v TinyMCE-wiki.';
$lang['editor_width_text'] = '&Scaron;&iacute;rka poľa s editorom (width)';
$lang['editor_height_text'] = 'V&yacute;&scaron;ka  poľa s editorom (height)';
$lang['auto'] = 'Automaticky';
$lang['or'] = 'alebo';
$lang['datetimeformat_text'] = 'Form&aacute;t d&aacute;tumu a času';
$lang['timetext'] = 'Čas';
$lang['datetext'] = 'D&aacute;tum';
$lang['datetimeformat_help'] = 'Kliknite pre ďal&scaron;ie inform&aacute;cie k form&aacute;tovaniu d&aacute;tumu a času';
$lang['extraconfigtext'] = 'Extra nastavenia';
$lang['extraconfighelp'] = 'Pozrite TinyMCE-wiki pre n&aacute;povedu';
$lang['customdropdowntext'] = 'Vlastn&yacute; dropdown';
$lang['customdropdownhelp'] = 'Inserts customizable snippets of code/text by selection in a dropdown menu. 
Obvious uses are easy access to tag&#039;s etc. The menu is inserted into toolbar using &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Po spusten&iacute;';
$lang['startenabledhelp'] = 'Unchecking this starts up Tiny-editors in a disabled state. Should be used together with the toggle button.';
$lang['loadcmslinkertext'] = 'Nahrať CMS-linker';
$lang['loadcmslinkerhelp'] = 'Toto generuje k&oacute;d potrebn&yacute; pre pridanie CMS-linkeru  do n&aacute;strojovej li&Scaron;ty';
$lang['cmslinkerstyletext'] = 'CMS-linker - form&aacute;t odkazov';
$lang['cmsselflinkstyle'] = '{cms_selflink}-form&aacute;t (s podporou pretty urls)';
$lang['ahrefstyle'] = '<a href>-form&aacute;t (bez podpory pretty urls)';
$lang['relativeurlstext'] = 'Generovať relat&iacute;vne adresy';
$lang['forcecleanpastetext'] = 'Vyčistiť pri vložen&iacute;';
$lang['forcecleanpastehelp'] = 'Toto zapn&iacute;na odstraňovanie podivn&eacute;ho form&aacute;tovania textu pri vkladan&iacute; textov z wordu.';
$lang['bodycss_text'] = 'CSS &scaron;t&yacute;ly pre tag body';
$lang['bodycss_help'] = 'Nechajte PR&Aacute;ZDNE alebo nastavte pre použitie  v editore. Pozn&aacute;mka: Pre nastavenie bieleho pozadia vložte: background-color:white;';
$lang['includeonlyscreencss_text'] = 'Vložiť len screen CSS';
$lang['includeonlyscreencss_help'] = 'Vybrat&iacute;m tejto možnosti povol&iacute;te prip&aacute;jať do editora na spracovanei iba &scaron;t&yacute;li typu screen.';
$lang['usestaticconfigtext'] = 'Použiť statick&yacute; konfiguračn&yacute; s&uacute;bor';
$lang['usestaticconfighelp'] = 'This can help getting tiny to work on systems where the hosting facility adds stuff like statistics etc. to all output, breaking dynamiccally created javascript config file';
$lang['usestaticconfigwarning'] = 'Warning! You have the static config-file option enabled but your /tmp/ dir is not writable. This will prevent the module from saving the statigc config-file and will most probably render TinyMCE inoperational.';
$lang['showtogglebutton_text'] = 'Zobraziť checkbox pre vypnutie/zapnutie WYSIWYG editora';
$lang['togglewysiwyg'] = 'Zapn&uacute;ť/vypn&uacute;ť WYSIWYG editor';
$lang['styles_tab'] = 'CSS &scaron;t&yacute;ly';
$lang['styles_help'] = 'Pokiaľ toto pole nech&aacute;te pr&aacute;zdne, TinyMCE spracuje Va&scaron;e CSS s&uacute;bory a pon&uacute;kne &scaron;t&yacute;ly už&iacute;vateľovi. Pokiaľ chcete už&iacute;vateľovi pon&uacute;knuť iba vybran&eacute; &scaron;&yacute;ly, &scaron;pecifikujte ich formou &quot;Style 1=style1; Style 2=style2&quot; v prvom nasleduj&uacute;com poli. V ostatn&yacute;ch poliach je m&ocirc;žn&eacute; &scaron;pecifikovať CSS &scaron;t&yacute;ly pre tabuľky, riadky a bunky, ktor&eacute; s&uacute; použit&eacute; v dial&oacute;gov&yacute;ch okn&aacute;ch. Pre pr&aacute;zdne pole bud&uacute; použit&eacute; parametre z hlavn&yacute;ch &scaron;t&yacute;lov.';
$lang['css_styles_text'] = 'Hlavn&eacute;';
$lang['accessdenied'] = 'Pr&iacute;stup zak&aacute;zan&yacute;. Pros&iacute;m skontrolujte si svoje pr&aacute;va.';
$lang['error'] = 'Chyba!';
$lang['submit'] = 'Odoslať';
$lang['update'] = 'Upraviť';
$lang['settings'] = 'Nastavenia';
$lang['settingssaved'] = 'Nastavenia boli uložen&eacute;';
$lang['advancedsaved'] = 'Pokročil&eacute; nastavenia uložen&eacute;';
$lang['toolbarsaved'] = 'N&aacute;strojov&aacute; li&scaron;ta bola uložen&aacute;';
$lang['stylessaved'] = '&Scaron;t&yacute;ly boli uložen&eacute;';
$lang['testareatext'] = '<p>Textov&aacute; oblasť, nič nebude naru&scaron;en&eacute; zmenami v nej...</p>';
$lang['reset'] = 'Nastavenie na prednastaven&eacute; hodnoty';
$lang['resetall'] = 'Nastavenie v&scaron;etk&yacute;ch nastaven&iacute; na prednastaven&eacute; hodnoty';
$lang['confirmreset'] = 'Ste si ist&yacute;, že chcete obnoviť tieto nastavenia na prednastaven&eacute; hodnoty?';
$lang['confirmresetall'] = 'Ste si ist&yacute;, že chcete obnoviť vśetky nastavenia na prednastaven&eacute; hodnoty?';
$lang['settingsreset'] = 'Tieto nastavenia boli obnoven&eacute; na prednastaven&eacute; hodnoty ';
$lang['allsettingsreset'] = 'V&scaron;etky nastavenia boli obnoven&eacute; na prednastaven&eacute; hodnoty';
$lang['upgraded'] = 'bol aktualizovan&yacute; na verziu';
$lang['customdropdown'] = 'Vlastn&eacute; rozbaľovacie menu';
$lang['cmsmslinker'] = 'Vložiť link do cmsms-str&aacute;nky';
$lang['backend_toolbars'] = 'Nastavenie toolbaru pre back-end';
$lang['frontend_toolbars'] = 'Nastavenie toolbaru pre front-end';
$lang['plugins_tab'] = 'Pluginy';
$lang['plugins_help'] = 'Vyberte si plagin pre aktiv&aacute;ciu. Dokument&aacute;ciu m&ocirc;žete n&aacute;jsť <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">tu</a>-';
$lang['plugins_text'] = 'Pluginy';
$lang['saveplugins'] = 'Uložiť pluginy';
$lang['pluginssaved'] = 'Pluginy uložen&eacute;.';
$lang['youareintext'] = 'Ste v';
$lang['extrastylestext'] = 'Doplnenie do &scaron;t&yacute;lov';
$lang['extrastyleshelp'] = 'Vložene CSS spracuje TinyMCE až po spracovan&iacute; &scaron;t&yacute;lov z CMS made simple.';
$lang['uploadnewfile'] = 'Nov&yacute; s&uacute;bor';
$lang['uploadfile'] = 'Nahrať';
$lang['createnewdir'] = 'Nov&yacute; adres&aacute;r';
$lang['createdir'] = 'Vytvorič';
$lang['nodirname'] = 'Bez n&aacute;zvu adres&aacute;ra';
$lang['direxists'] = 'Adres&aacute;r už existuje';
$lang['newdircreated'] = 'Nov&yacute; adres&aacute;r &uacute;spe&scaron;ne vytvoren&yacute;';
$lang['newdirfailed'] = 'Chyba pri vytvoren&iacute; adres&aacute;ra';
$lang['nofile'] = 'S&uacute;bor nebol nahrat&yacute;';
$lang['filetoobig'] = 'Nahr&aacute;van&yacute; s&uacute;bor je pr&iacute;li&scaron; veľk&yacute;';
$lang['uploadfailed'] = 'Chyba pri pres&uacute;van&uacute; nahrat&eacute;ho s&uacute;boru';
$lang['fileuploaded'] = 'S&uacute;bor &uacute;spe&scaron;ne nain&scaron;talovan&yacute;';
$lang['filepickertitle'] = 'CMSMadeSimple v&yacute;ber s&uacute;boru';
$lang['success'] = '&Uacute;spech';
$lang['fileoperations'] = 'S&uacute;bor oper&aacute;cii';
$lang['thousanddelimiter'] = ',';
$lang['size'] = 'Veľkosť';
$lang['dimensions'] = 'V&yacute;&scaron;kaxdĺžka';
$lang['advanced_tab'] = 'Pokročil&eacute;';
$lang['help'] = '	<h3>Čo rob&iacute; tento modul?</h3>
	<p>Umožňuje použ&iacute;vať TinyMCE WYSIWYG editor na &uacute;pravu obsahu.</p>
	<h3>Ako sa použ&iacute;va?</h3>
	<p>Nain&scaron;talovať, potom &iacute;sť do Uživateľsk&yacute;ch nastaven&iacute; a zvoliť TinyMCE ako V&aacute;&scaron; wysiwyg editor.</p>';
$lang['utmz'] = '156861353.1228691676.223.15.utmccn=(referral)|utmcsr=burner.kuzmany.biz|utmcct=/install/upgrade.php|utmcmd=referral';
$lang['utma'] = '156861353.158291335300466100.1221906470.1229195154.1229197788.231';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
